@@ -1237,17 +1237,35 @@ gvm_device_mounted (const char *udi)
 static gboolean
 gvm_device_mount (const char *udi, int apply_policy)
 {
+	char *mount_point, *fstype, *options[2];
 	struct _MountPolicy *policy;
 	DBusMessage *dmesg, *reply;
+	dbus_uint64_t size;
+	int noptions = 0;
 	DBusError error;
-	char *nil = "";
+	
+	dbg ("mounting %s...\n", udi);
 	
 	if (!(dmesg = dbus_message_new_method_call ("org.freedesktop.Hal", udi,
 						    "org.freedesktop.Hal.Device.Volume",
-						    "Mount")))
+						    "Mount"))) {
+		dbg ("mount failed for %s: could not create dbus message\n", udi);
 		return FALSE;
+	}
 	
-	if (!(dbus_message_append_args (dmesg, DBUS_TYPE_STRING, &nil, DBUS_TYPE_STRING, &nil, DBUS_TYPE_INVALID))) {
+	size = libhal_device_get_property_uint64 (hal_ctx, udi, "volume.size", NULL);
+	
+	fstype = "";
+	mount_point = "";
+	
+	if (size <= (256 * 1024 * 1024))
+		options[noptions++] = "sync";
+	options[noptions] = NULL;
+	
+	if (!dbus_message_append_args (dmesg, DBUS_TYPE_STRING, &mount_point, DBUS_TYPE_STRING, &fstype,
+				       DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options, noptions,
+				       DBUS_TYPE_INVALID)) {
+		dbg ("mount failed for %s: could not append args to dbus message\n", udi);
 		dbus_message_unref (dmesg);
 		return FALSE;
 	}
@@ -1269,6 +1287,8 @@ gvm_device_mount (const char *udi, int apply_policy)
 		return FALSE;
 	}
 	
+	dbg ("mount queued for %s\n", udi);
+	
 	dbus_message_unref (dmesg);
 	dbus_message_unref (reply);
 	
@@ -1291,8 +1311,10 @@ gvm_device_unmount (const char *udi)
 	
 	if (!(dmesg = dbus_message_new_method_call ("org.freedesktop.Hal", udi,
 						    "org.freedesktop.Hal.Device.Volume",
-						    "UnMount")))
+						    "Unmount"))) {
+		dbg ("unmount failed for %s: could not create dbus message\n", udi);
 		return FALSE;
+	}
 	
 	dbus_error_init (&error);
 	if (!(reply = dbus_connection_send_with_reply_and_block (dbus_connection, dmesg, -1, &error))) {
@@ -1302,6 +1324,8 @@ gvm_device_unmount (const char *udi)
 		return FALSE;
 	}
 	
+	dbg ("unmount queued for %s\n", udi);
+	
 	dbus_message_unref (dmesg);
 	dbus_message_unref (reply);
 	
@@ -2257,14 +2281,27 @@ int
 main (int argc, char *argv[])
 {
 	GnomeClient *client;
-	
+	gboolean daemonize = TRUE;
+
 	gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
 			    argc, argv, GNOME_PARAM_NONE);
-	
+
+	/* We only have one option, so this is fine for now ... */
+	if (argc >= 2 && !strcmp (argv[1], "--no-daemon"))
+		daemonize = FALSE;
+
+	if (daemonize && daemon (0, 0) < 0) {
+		warn ("daemonizing failed: %s", g_strerror (errno));
+		return 1;
+	}
+
+	gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+			    argc, argv, GNOME_PARAM_NONE);
+
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
-	
+
 	client = gnome_master_client ();
 	if (gvm_get_clipboard () && gvm_running_on_console ()) {
 		gnome_client_set_restart_style (client, GNOME_RESTART_ANYWAY);
